LoadCachedFragilityCurveMultiple

fragility_curves.LoadCachedFragilityCurveMultiple()

Maakt het mogelijk om een vooraf berekende (cached) fragility curve in te laden.

Deze class doet het voor een meerdere vakken en meerdere faalmechanisme.


data_adapter : DataAdapter Adapter for handling data input and output operations.

df_out : Optional[pd.DataFrame] | None Output DataFrame containing the final fragility curve

Notes

Default waarden te overschrijven in de global variables (let op: LoadCachedFragilityCurve):

  • default_measure_id: int Standaard measure_id die gebruikt wordt als basis fragility curve, standaard 0.

Attributes

Name Description
cache_fragility_curve_schema dict() -> new empty dictionary
data_adapter
df_in The type of the None singleton.
df_out The type of the None singleton.
failuremechanism_id_to_measure_id_schema dict() -> new empty dictionary
loaded_curve The type of the None singleton.
measure_to_effect_schema dict() -> new empty dictionary
section_id_to_measure_id_schema dict() -> new empty dictionary

Methods

Name Description
log_exceptions Stuurt exceptions eerst naar de logger van de DataAdapter
retrieve_cache Functie om hergebruik toe te staan van LoadCachedFragilityCurveOneFailureMechanism door LoadCachedFragilityCurve
retrieve_cache_for_multiple_failure_mechanisms Functie om hergebruik toe te staan van LoadCachedFragilityCurve door LoadCachedFragilityCurveMultiple
run Runt de het ophalen van een voorberekende fragility curve voor meerdere vakken en voor meerdere faalmechanisme.

log_exceptions

fragility_curves.LoadCachedFragilityCurveMultiple.log_exceptions(method)

Stuurt exceptions eerst naar de logger van de DataAdapter

retrieve_cache

fragility_curves.LoadCachedFragilityCurveMultiple.retrieve_cache(
    df_fragility_curves,
    df_measures_to_effect,
    measure_id,
)

Functie om hergebruik toe te staan van LoadCachedFragilityCurveOneFailureMechanism door LoadCachedFragilityCurve

retrieve_cache_for_multiple_failure_mechanisms

fragility_curves.LoadCachedFragilityCurveMultiple.retrieve_cache_for_multiple_failure_mechanisms(
    df_fragility_curves,
    df_measures_to_effect,
    measure_id,
)

Functie om hergebruik toe te staan van LoadCachedFragilityCurve door LoadCachedFragilityCurveMultiple

run

fragility_curves.LoadCachedFragilityCurveMultiple.run(
    input,
    output,
    measure_id=None,
)

Runt de het ophalen van een voorberekende fragility curve voor meerdere vakken en voor meerdere faalmechanisme.

Parameters

Name Type Description Default
input list[str] Naam van de input dataadapter: fragility curves, Hierbij zijn de fragility curves voor meerdere faalmechanisme, dijkvak en measure_ids. required
output str Naam van de dataadapter Fragility curve output required
measure_id int | None Measure_id van de fragility curve die ingeladen moet worden. None

Raises

Name Type Description
AssertionError Als input een string is, maar measure_id is None.

Notes