LoadsCIWhatIf
loads.LoadsCIWhatIf()Met deze functie worden belasting opgehaald en weggeschreven.
Attributes
| Name | Description |
|---|---|
| data_adapter | |
| df_in | The type of the None singleton. |
| df_out | The type of the None singleton. |
Methods
| Name | Description |
|---|---|
| log_exceptions | Stuurt exceptions eerst naar de logger van de DataAdapter |
| run | De runner van de Loads Classify. |
log_exceptions
loads.LoadsCIWhatIf.log_exceptions(method)Stuurt exceptions eerst naar de logger van de DataAdapter
run
loads.LoadsCIWhatIf.run(input, output)De runner van de Loads Classify.
Args: input (str):
output (str):
Returns: Dataframe: Pandas dataframe met …