get_waterinfo_thresholds
loads.get_waterinfo_thresholds(location_code, parameter_id='waterhoogte')Haal voor Waterinfo de thresholds op voor de opgegegeven parameter.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| location_code | str | Locatiecode van de waterinfo locatie | required |
| parameter_id | str | Waterinfo parameter bij geen waarde ‘waterhoogte’ | 'waterhoogte' |
Notes
Gebruikte API: https://waterinfo.rws.nl/api/chart/get
Returns
| Name | Type | Description |
|---|---|---|
| Dataframe | Pandas dataframe met thresholds |
Raises
| Name | Type | Description |
|---|---|---|
| ConnectionError | Als de verbinding met de API niet lukt of geen thresholds zijn gevonden |