GwdiInference
gwdi.GwdiInference()Run GWDI inference for all raster cells in the climate inputs.
Attributes
| Name | Type | Description |
|---|---|---|
| data_adapter | DataAdapter | Toolbox data-adapter used for all configured input and output access. |
| df_in | dict[str, object] | None | Cached runtime inputs loaded by :meth:_load_inputs. |
| df_out | pd.DataFrame | None | Cached GWDI output after :meth:run. |
| input_order | ClassVar[tuple[str, …]] | Required order of GWDI input adapter names. |
| precipitation_schema | ClassVar[dict[str, str | list[str]]] | Schema contract for precipitation input (time, fid, P). |
| evaporation_schema | ClassVar[dict[str, str | list[str]]] | Schema contract for evaporation input (time, fid, evaporation). |
| location_info_schema | ClassVar[dict[str, str | list[str]]] | Schema contract for location metadata input (location, position). |
Methods
| Name | Description |
|---|---|
| log_exceptions | Stuurt exceptions eerst naar de logger van de DataAdapter |
| run | Execute GWDI inference for all available fid values. |
log_exceptions
gwdi.GwdiInference.log_exceptions(method)Stuurt exceptions eerst naar de logger van de DataAdapter
run
gwdi.GwdiInference.run(input, output)Execute GWDI inference for all available fid values.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| input | list[str] | Input adapter names in this exact order: [precipitation, evaporation, location_info, pastas_models, df_stats_minima]. Expected adapter payload contracts: - precipitation: dataframe with time, fid, P. - evaporation: dataframe with time, fid, evaporation. - location_info: dataframe with location, position. - pastas_models: dictionary of loaded Pastas models. - df_stats_minima: dataframe with return periods as index and location names as columns. |
required |
| output | str | Output adapter name that receives GWDI rows with columns: fid, parameterid, methodid, datetime, value, peilbuisid. |
required |